import FinanceCalculator from "@/components/finance-calculator"
import { UserNav } from "@/components/auth/user-nav"
import { LoginSuggestion } from "@/components/login-suggestion"
import { Metadata } from "next"

export const metadata: Metadata = {
  title: "智能理财计算器 - 专业的投资收益分析工具",
  description: "免费在线理财计算器，支持多币种投资收益计算、年化收益率分析、投资组合管理。科学规划投资，精准计算理财产品收益，助您做出明智投资决策。",
  keywords: ["理财计算器", "投资收益计算", "年化收益率", "理财工具", "投资分析", "收益计算", "理财规划"],
}

export default function Home() {
  return (
    <main className="container mx-auto py-8 px-4 bg-background transition-colors">
      <div className="flex justify-between items-center mb-6">
        <div>
          <h1 className="text-3xl font-bold mb-2 text-foreground">智能理财计算器</h1>
          <p className="text-lg text-muted-foreground">专业的投资收益分析工具，助您科学理财</p>
        </div>
        <UserNav />
      </div>
      
      <div className="mb-8">
        <div className="bg-muted/50 rounded-lg p-6 mb-6 border">
          <h2 className="text-xl font-semibold mb-3 text-foreground">功能特色</h2>
          <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-4 text-sm">
            <div className="flex items-center space-x-2">
              <span className="w-2 h-2 bg-primary rounded-full"></span>
              <span className="text-foreground">多币种支持（人民币、美元、欧元等）</span>
            </div>
            <div className="flex items-center space-x-2">
              <span className="w-2 h-2 bg-primary rounded-full"></span>
              <span className="text-foreground">自动计算年化收益率</span>
            </div>
            <div className="flex items-center space-x-2">
              <span className="w-2 h-2 bg-primary rounded-full"></span>
              <span className="text-foreground">投资组合管理</span>
            </div>
            <div className="flex items-center space-x-2">
              <span className="w-2 h-2 bg-primary rounded-full"></span>
              <span className="text-foreground">数据安全云端存储</span>
            </div>
            <div className="flex items-center space-x-2">
              <span className="w-2 h-2 bg-primary rounded-full"></span>
              <span className="text-foreground">实时收益计算</span>
            </div>
            <div className="flex items-center space-x-2">
              <span className="w-2 h-2 bg-primary rounded-full"></span>
              <span className="text-foreground">支持备注管理</span>
            </div>
          </div>
        </div>

        {/* 登录建议组件 */}
        <LoginSuggestion />
      </div>
      
      <FinanceCalculator />
      
      <footer className="mt-12 pt-8 border-t border-border">
        <div className="text-center text-sm text-muted-foreground">
          <p className="mb-2">
            智能理财计算器是一款专业的在线投资收益分析工具，帮助投资者科学计算理财产品收益，
            支持多种货币类型，提供精准的年化收益率分析，让您的投资决策更加明智。
          </p>
          <p>
            © 2024 智能理财计算器. 专注于为用户提供专业、安全、便捷的理财计算服务。
          </p>
        </div>
      </footer>
    </main>
  )
}
