"use client"

import { useSession, signIn } from "next-auth/react"
import { Button } from "@/components/ui/button"
import { Card, CardContent, CardHeader, CardTitle } from "@/components/ui/card"
import { Alert, AlertDescription } from "@/components/ui/alert"
import { LogIn, AlertTriangle, Cloud, Shield, RefreshCw } from "lucide-react"

export function LoginSuggestion() {
  const { data: session, status } = useSession()

  // 如果已登录，不显示此组件
  if (status === "authenticated" || status === "loading") {
    return null
  }

  const loginFeatures = [
    {
      icon: <Cloud className="h-4 w-4" />,
      title: "云端数据存储",
      description: "数据安全存储在云端，永不丢失"
    },
    {
      icon: <RefreshCw className="h-4 w-4" />,
      title: "多设备同步",
      description: "在不同设备间同步您的理财数据"
    },
    {
      icon: <Shield className="h-4 w-4" />,
      title: "数据备份保护",
      description: "专业的数据备份和恢复机制"
    }
  ]

  return (
    <div className="space-y-4">
      {/* 警告提示 */}
      <Alert className="border-orange-200 bg-orange-50 text-orange-800 dark:border-orange-800 dark:bg-orange-950 dark:text-orange-200">
        <AlertTriangle className="h-4 w-4" />
        <AlertDescription>
          <strong>重要提醒：</strong>当前未登录状态下，您的数据仅存储在本地浏览器中。
          清理浏览器数据或更换设备后，数据将会丢失。建议您登录账号以享用云端存储服务。
        </AlertDescription>
      </Alert>

      {/* 登录建议卡片 */}
      <Card className="border-blue-200 bg-blue-50/50 dark:border-blue-800 dark:bg-blue-950/50">
        <CardHeader className="pb-3">
          <CardTitle className="flex items-center gap-2 text-lg text-blue-800 dark:text-blue-200">
            <LogIn className="h-5 w-5" />
            建议登录账号
          </CardTitle>
        </CardHeader>
        <CardContent className="space-y-4">
          <p className="text-sm text-blue-700 dark:text-blue-300 mb-4">
            登录后可享受以下专业功能，让您的理财管理更安全、更便捷：
          </p>
          
          <div className="grid grid-cols-1 md:grid-cols-3 gap-3">
            {loginFeatures.map((feature, index) => (
              <div key={index} className="flex items-start space-x-2 p-3 bg-white dark:bg-gray-800 rounded-lg border border-blue-100 dark:border-blue-800">
                <div className="text-blue-600 dark:text-blue-400 mt-0.5">
                  {feature.icon}
                </div>
                <div className="flex-1 min-w-0">
                  <h4 className="text-sm font-medium text-blue-800 dark:text-blue-200 mb-1">
                    {feature.title}
                  </h4>
                  <p className="text-xs text-blue-600 dark:text-blue-400">
                    {feature.description}
                  </p>
                </div>
              </div>
            ))}
          </div>

          <div className="pt-2 flex justify-center">
            <Button 
              onClick={() => signIn()} 
              className="bg-blue-600 hover:bg-blue-700 dark:bg-blue-600 dark:hover:bg-blue-700 text-white px-6"
            >
              <LogIn className="h-4 w-4 mr-2" />
              立即登录
            </Button>
          </div>
        </CardContent>
      </Card>
    </div>
  )
} 